package de.spacecontrol.sc.dllwrapper;

import java.util.ArrayList;
import javax.swing.JOptionPane;

public class ScDllWrapper {
  public static final int LED_NUM = 33;
  
  public static final int MAX_BRIGHTNESS = 15;
  
  public static final int NOTHING_CHANGED = -1;
  
  public static final int BSC_SETTINGS_CHANGED = 131072;
  
  public static final int ADV_SETTINGS_CHANGED = 131073;
  
  public static final int DEV_PARS_CHANGED = 131074;
  
  public static final int DEV_ERR_UNKNOWN_COMMAND = 131075;
  
  public static final int DEV_ERR_INVALID_VALUE = 131076;
  
  public static final int DEV_ERR_PARSE_ERROR = 131077;
  
  public static final int DEV_ERR_INTERNAL_ERROR = 131078;
  
  public static final int DEV_ERR_INVALID_ID = 131079;
  
  public static final int DEV_ERR_BUF_OVERFLOW = 131080;
  
  public static final int DEV_FRONT = 131081;
  
  public static final int DEV_RIGHT = 131082;
  
  public static final int DEV_TOP = 131083;
  
  public static final int DEV_FIT = 131084;
  
  public static final int DEV_WHEEL_LEFT = 131085;
  
  public static final int DEV_WHEEL_RIGHT = 131086;
  
  public static final int EVT_HNDL_SENS_DLG = 131087;
  
  public static final int EVT_HNDL_THRESH_DLG = 131088;
  
  public static final int EVT_HNDL_LCD_DLG = 131089;
  
  public static final int EVT_HNDL_LEDS_DLG = 131090;
  
  public static final int EVT_APPL_IN_FRGRND = 131091;
  
  public static final int EVT_HNDL_KBD_DLG = 131092;
  
  public static final int EVT_HNDL_WFL_DLG = 131093;
  
  public static final int DEV_BACK = 131094;
  
  public static final int DEV_LEFT = 131095;
  
  public static final int DEV_BOTTOM = 131096;
  
  public static final int DEV_CTRL = 131097;
  
  public static final int APPL_FUNC_START = 131104;
  
  public static final String CMD_UPDATE_FIRMWARE = "0";
  
  public static final String CMD_UPDATE_FIRMWARE_GUI = "1";
  
  public static final String CMD_ACCEPT_ALL_FTDIS = "2";
  
  public static final String CMD_BLINK_LEDS = "3";
  
  public static final String CMD_INJECT_STRING = "4";
  
  public static final String CMD_SET_FAKE_ZERO = "7";
  
  public static final int BAUD = 0;
  
  public static final int MAX_BYTES_IN_RX_QUEUE = 1;
  
  public static final int PORT = 2;
  
  public static final int CFG_AUTO_CHANGE = 3;
  
  public static final int REMEMBER_LAST_CONFIG = 4;
  
  public static final int DISABLE_CUBE_DEMO = 5;
  
  public static final int EXPLORER_DELAY = 6;
  
  public static final int DEVICE_TIMEOUT = 7;
  
  public static final int SEND_MODE = 8;
  
  public static final int SEND_DELAY = 9;
  
  public static final int CAP_CHARACTERISTIC = 10;
  
  public static final int SINGLE_COM_PER_APPL = 11;
  
  public static final int ENABLE_LEGACY_COM1 = 12;
  
  public static final int ENABLE_LEGACY_COM2 = 13;
  
  public static final int BLINK_PERIOD = 14;
  
  public static final int SEARCH_TOP_WINDOW = 15;
  
  public static final int SKIP_TIMEOUT = 16;
  
  public static final int TIME_BEFORE_SLEEPING = 17;
  
  public static final int WHEEL_ACCELERATOR = 18;
  
  public static final int DEVICE_CHECKING_TIME = 19;
  
  private static boolean loadLibrary(ArrayList<String> paramArrayList) {
    boolean bool = false;
    String str = "";
    for (String str1 : paramArrayList) {
      try {
        System.load(str1);
        System.out.println("Library loaded: " + str1);
        bool = true;
        break;
      } catch (UnsatisfiedLinkError unsatisfiedLinkError) {
        str = str + str1 + "\n";
      } 
    } 
    if (!bool)
      JOptionPane.showMessageDialog(null, "Loading\n" + str + "\nfailed!", "Load Error", 0); 
    return bool;
  }
  
  public static String eventToString(int paramInt) {
    if (paramInt < 131072)
      return "Key event " + paramInt; 
    switch (paramInt) {
      case -1:
        return "NOTHING_CHANGED";
      case 131072:
        return "BSC_SETTINGS_CHANGED";
      case 131073:
        return "ADV_SETTINGS_CHANGED";
      case 131074:
        return "DEV_PARS_CHANGED";
      case 131075:
        return "DEV_ERR_UNKNOWN_COMMAND";
      case 131076:
        return "DEV_ERR_INVALID_VALUE";
      case 131077:
        return "DEV_ERR_PARSE_ERROR";
      case 131078:
        return "DEV_ERR_INTERNAL_ERROR";
      case 131079:
        return "DEV_ERR_INVALID_ID";
      case 131080:
        return "DEV_ERR_BUF_OVERFLOW";
      case 131081:
        return "DEV_FRONT";
      case 131082:
        return "DEV_RIGHT";
      case 131083:
        return "DEV_TOP";
      case 131084:
        return "DEV_FIT";
      case 131086:
        return "DEV_WHEEL_RIGHT";
      case 131085:
        return "DEV_WHEEL_LEFT";
      case 131087:
        return "EVT_HNDL_SENS_DLG";
      case 131088:
        return "EVT_HNDL_THRESH_DLG";
      case 131089:
        return "EVT_HNDL_LCD_DLG";
      case 131090:
        return "EVT_HNDL_LEDS_DLG";
      case 131091:
        return "EVT_APPL_IN_FRGRND";
      case 131092:
        return "EVT_HNDL_KBD_DLG";
      case 131093:
        return "EVT_HNDL_WFL_DLG";
      case 131094:
        return "DEV_BACK";
      case 131095:
        return "DEV_LEFT";
      case 131096:
        return "DEV_BOTTOM";
      case 131097:
        return "DEV_CTRL";
    } 
    return "Unknown event " + paramInt;
  }
  
  private static ScStatus intToStatus(int paramInt) {
    switch (paramInt) {
      case 0:
        return ScStatus.SC_OK;
      case 1:
        return ScStatus.SC_COMMUNICATION_ERROR;
      case 2:
        return ScStatus.SC_WRONG_DEVICE_INDEX;
      case 3:
        return ScStatus.SC_PARAMETER_OUT_OF_RANGE;
      case 4:
        return ScStatus.SC_FILE_IO_ERROR;
      case 5:
        return ScStatus.SC_KEYSTROKE_ERROR;
      case 6:
        return ScStatus.SC_APPL_NOT_FOUND;
      case 7:
        return ScStatus.SC_REGISTRY_ERROR;
      case 8:
        return ScStatus.SC_NOT_SUPPORTED;
      case 9:
        return ScStatus.SC_EXEC_CMD_ERROR;
      case 10:
        return ScStatus.SC_THREAD_ERROR;
      case 11:
        return ScStatus.SC_WRONG_USER;
    } 
    return ScStatus.SC_ERR_END;
  }
  
  public static void scIsProcessRunning(ScOneString paramScOneString, ScOneBoolean paramScOneBoolean) {
    isProcessRunning(paramScOneString, paramScOneBoolean);
  }
  
  public static void scSetCurrentUserRegValue(ScThreeStrings paramScThreeStrings) throws ScEx {
    int i = setCurrentUserRegValue(paramScThreeStrings);
    throwScEx(i);
  }
  
  public static void scQueryCurrentUserRegValue(ScTwoStrings paramScTwoStrings, int paramInt, ScOneString paramScOneString) throws ScEx {
    int i = queryCurrentUserRegValue(paramScTwoStrings, paramInt, paramScOneString);
    throwScEx(i);
  }
  
  public static void scDelCurrentUserRegValue(ScTwoStrings paramScTwoStrings) throws ScEx {
    int i = delCurrentUserRegValue(paramScTwoStrings);
    throwScEx(i);
  }
  
  public static void scConnect2(boolean paramBoolean, String paramString) throws ScEx {
    ScOneBoolean scOneBoolean = new ScOneBoolean(paramBoolean);
    ScOneString scOneString = (paramString == null) ? new ScOneString("") : new ScOneString(paramString);
    int i = connect2(scOneBoolean, scOneString);
    throwScEx(i);
  }
  
  public static void scConnect() throws ScEx {
    int i = connect();
    throwScEx(i);
  }
  
  private static void throwScEx(int paramInt) throws ScEx {
    switch (paramInt) {
      case 0:
        return;
      case 1:
        throw new ScComErrEx();
      case 2:
        throw new ScWrongDevIdxEx();
      case 3:
        throw new ScParOutOfRangeEx();
      case 4:
        throw new ScFileIoEx();
      case 5:
        throw new ScKeystrokeEx();
      case 6:
        throw new ScApplNotFoundEx();
      case 7:
        throw new ScRegistryEx();
      case 8:
        throw new ScNotSupportedEx();
      case 9:
        throw new ScExecCmdErrEx();
      case 10:
        throw new ScThreadErrEx();
      case 11:
        throw new ScWrongUserEx();
    } 
    throw new ScEx();
  }
  
  public static void scDisconnect() throws ScEx {
    int i = disconnect();
    throwScEx(i);
  }
  
  public static void scStop() throws ScEx {
    int i = stop();
    throwScEx(i);
  }
  
  public static void scGetDmnVrsn(ScTwoStrings paramScTwoStrings) throws ScEx {
    int i = getDmnVrsn(paramScTwoStrings);
    throwScEx(i);
  }
  
  public static void scGetDevNum(ScThreeInts paramScThreeInts) throws ScEx {
    int i = getDevNum(paramScThreeInts);
    throwScEx(i);
  }
  
  public static void scGetFgAppl(ScTwoStrings paramScTwoStrings) throws ScEx {
    int i = getFgAppl(paramScTwoStrings);
    throwScEx(i);
  }
  
  public static void scGetDllLogPars(ScLogPars paramScLogPars) {
    getDllLogPars(paramScLogPars);
  }
  
  public static void scSetDllLogPars(ScLogPars paramScLogPars) {
    setDllLogPars(paramScLogPars);
  }
  
  public static void scSetState2(String paramString) throws ScEx {
    ScOneString scOneString = new ScOneString(paramString);
    int i = setState2(scOneString);
    throwScEx(i);
  }
  
  public static void scSetState(ScTwoStrings paramScTwoStrings) throws ScEx {
    int i = setState(paramScTwoStrings);
    throwScEx(i);
  }
  
  public static void scSetMode(ScOneInt paramScOneInt) throws ScEx {
    int i = setMode(paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetDaemonPar(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getDaemonPar(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetDaemonPar(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setDaemonPar(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetDevInfo(int paramInt, ScDevInfo paramScDevInfo) throws ScEx {
    int i = getDevInfo(paramInt, paramScDevInfo);
    throwScEx(i);
  }
  
  public static void scGetDefDevPars(int paramInt, ScDevPars paramScDevPars) throws ScEx {
    int i = getDefDevPars(paramInt, paramScDevPars);
    throwScEx(i);
  }
  
  public static void scGetDevPars(int paramInt, ScDevPars paramScDevPars) throws ScEx {
    int i = getDevPars(paramInt, paramScDevPars);
    throwScEx(i);
  }
  
  public static void scSetDevPars(int paramInt, ScDevPars paramScDevPars) throws ScEx {
    int i = setDevPars(paramInt, paramScDevPars);
    throwScEx(i);
  }
  
  public static void scSetDevParsToDefaults(int paramInt, ScDevPars paramScDevPars) throws ScEx {
    int i = setDevParsToDefaults(paramInt, paramScDevPars);
    throwScEx(i);
  }
  
  public static void scGetBasicSettings(int paramInt, ScBasicSettings paramScBasicSettings) throws ScEx {
    int i = getBasicSettings(paramInt, paramScBasicSettings);
    throwScEx(i);
  }
  
  public static void scSetBasicSettings(int paramInt, ScBasicSettings paramScBasicSettings) throws ScEx {
    int i = setBasicSettings(paramInt, paramScBasicSettings);
    throwScEx(i);
  }
  
  public static void scGetAdvancedSettings(int paramInt, ScAdvancedSettings paramScAdvancedSettings) throws ScEx {
    int i = getAdvancedSettings(paramInt, paramScAdvancedSettings);
    throwScEx(i);
  }
  
  public static void scSetAdvancedSettings(int paramInt, ScAdvancedSettings paramScAdvancedSettings) throws ScEx {
    int i = setAdvancedSettings(paramInt, paramScAdvancedSettings);
    throwScEx(i);
  }
  
  public static void scGetAdvSens(int paramInt, ScAdvSens paramScAdvSens) throws ScEx {
    int i = getAdvSens(paramInt, paramScAdvSens);
    throwScEx(i);
  }
  
  public static void scSetAdvSens(int paramInt, ScAdvSens paramScAdvSens) throws ScEx {
    int i = setAdvSens(paramInt, paramScAdvSens);
    throwScEx(i);
  }
  
  public static void scGetStdMode(int paramInt, ScOneByte paramScOneByte) throws ScEx {
    int i = getStdMode(paramInt, paramScOneByte);
    throwScEx(i);
  }
  
  public static void scSetStdMode(int paramInt, ScOneByte paramScOneByte) throws ScEx {
    int i = setStdMode(paramInt, paramScOneByte);
    throwScEx(i);
  }
  
  public static void scGetCmprMode(int paramInt, ScOneByte paramScOneByte) throws ScEx {
    int i = getCmprMode(paramInt, paramScOneByte);
    throwScEx(i);
  }
  
  public static void scSetCmprMode(int paramInt, ScOneByte paramScOneByte) throws ScEx {
    int i = setCmprMode(paramInt, paramScOneByte);
    throwScEx(i);
  }
  
  public static void scGetSens(int paramInt, ScTwoInts paramScTwoInts) throws ScEx {
    int i = getSens(paramInt, paramScTwoInts);
    throwScEx(i);
  }
  
  public static void scSetSens(int paramInt, ScTwoInts paramScTwoInts) throws ScEx {
    int i = setSens(paramInt, paramScTwoInts);
    throwScEx(i);
  }
  
  public static void scGetXTraSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getXTraSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetXTraSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setXTraSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetYTraSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getYTraSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetYTraSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setYTraSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetZTraSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getZTraSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetZTraSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setZTraSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetXRotSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getXRotSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetXRotSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setXRotSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetYRotSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getYRotSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetYRotSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setYRotSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetZRotSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getZRotSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetZRotSens(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setZRotSens(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetSendDelay(int paramInt, ScTwoInts paramScTwoInts) throws ScEx {
    int i = getSendDelay(paramInt, paramScTwoInts);
    throwScEx(i);
  }
  
  public static void scSetSendDelay(int paramInt, ScTwoInts paramScTwoInts) throws ScEx {
    int i = setSendDelay(paramInt, paramScTwoInts);
    throwScEx(i);
  }
  
  public static void scGetNullRad(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getNullRad(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetNullRad(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setNullRad(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetStdZero(int paramInt) throws ScEx {
    int i = setStdZero(paramInt);
    throwScEx(i);
  }
  
  public static void scGetStdData(int paramInt, ScStdData paramScStdData) throws ScEx {
    int i = getStdData(paramInt, paramScStdData);
    throwScEx(i);
  }
  
  public static void scFetchStdData(int paramInt, ScStdData paramScStdData) throws ScEx {
    int i = fetchStdData(paramInt, paramScStdData);
    throwScEx(i);
  }
  
  public static void scGetRawData(int paramInt, byte[] paramArrayOfbyte) throws ScEx {
    int i = getRawData(paramInt, paramArrayOfbyte);
    throwScEx(i);
  }
  
  public static void scGetTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetXTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getXTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetXTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setXTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetYTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getYTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetYTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setYTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetZTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getZTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetZTra(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setZTra(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetXTraRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getXTraRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetXTraRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setXTraRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetYTraRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getYTraRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetYTraRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setYTraRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetZTraRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getZTraRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetZTraRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setZTraRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetXRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getXRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetXRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setXRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetYRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getYRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetYRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setYRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetZRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getZRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetZRot(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setZRot(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetXRotRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getXRotRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetXRotRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setXRotRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetYRotRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getYRotRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetYRotRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setYRotRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetZRotRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getZRotRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetZRotRev(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setZRotRev(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetDom(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = getDom(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scSetDom(int paramInt, ScOneBoolean paramScOneBoolean) throws ScEx {
    int i = setDom(paramInt, paramScOneBoolean);
    throwScEx(i);
  }
  
  public static void scGetCfgFileName(int paramInt, ScOneString paramScOneString) throws ScEx {
    int i = getCfgFileName(paramInt, paramScOneString);
    throwScEx(i);
  }
  
  public static void scSaveDevPars(int paramInt, ScOneString paramScOneString) throws ScEx {
    int i = saveDevPars(paramInt, paramScOneString);
    throwScEx(i);
  }
  
  public static void scSaveDevPars(int paramInt, String paramString) throws ScEx {
    ScOneString scOneString = new ScOneString(paramString);
    int i = saveDevPars(paramInt, scOneString);
    throwScEx(i);
  }
  
  public static void scLoadDevPars(int paramInt, ScOneString paramScOneString, ScDevPars paramScDevPars) throws ScEx {
    int i = loadDevPars(paramInt, paramScOneString, paramScDevPars);
    throwScEx(i);
  }
  
  public static void scLoadDevPars(int paramInt, String paramString, ScDevPars paramScDevPars) throws ScEx {
    ScOneString scOneString = new ScOneString(paramString);
    int i = loadDevPars(paramInt, scOneString, paramScDevPars);
    throwScEx(i);
  }
  
  public static void scPressKey(int paramInt1, int paramInt2) throws ScEx {
    int i = pressKey(paramInt1, paramInt2);
    throwScEx(i);
  }
  
  public static void scRelKey(int paramInt1, int paramInt2) throws ScEx {
    int i = relKey(paramInt1, paramInt2);
    throwScEx(i);
  }
  
  public static void scTriggerFunction(int paramInt1, int paramInt2) throws ScEx {
    int i = triggerFunction(paramInt1, paramInt2);
    throwScEx(i);
  }
  
  public static void scSetLeds(int paramInt, ScThreeInts paramScThreeInts) throws ScEx {
    int i = setLeds(paramInt, paramScThreeInts);
    throwScEx(i);
  }
  
  public static void scGetLed(int paramInt1, int paramInt2, ScOneInt paramScOneInt) throws ScEx {
    int i = getLed(paramInt1, paramInt2, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetLed(int paramInt1, int paramInt2, ScOneInt paramScOneInt) throws ScEx {
    int i = setLed(paramInt1, paramInt2, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetLedsEx(int paramInt, byte[] paramArrayOfbyte) throws ScEx {
    int i = getLedsEx(paramInt, paramArrayOfbyte);
    throwScEx(i);
  }
  
  public static void scSetLedsEx(int paramInt, byte[] paramArrayOfbyte) throws ScEx {
    int i = setLedsEx(paramInt, paramArrayOfbyte);
    throwScEx(i);
  }
  
  public static void scGetLcd(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = getLcd(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetLcd(int paramInt, ScOneInt paramScOneInt) throws ScEx {
    int i = setLcd(paramInt, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scSetLcdColor(int paramInt, ScThreeInts paramScThreeInts) throws ScEx {
    int i = setLcdColor(paramInt, paramScThreeInts);
    throwScEx(i);
  }
  
  public static void scSetDsplString(int paramInt1, int paramInt2, String paramString, ScOneInt paramScOneInt) throws ScEx {
    int i = setDsplString(paramInt1, paramInt2, paramString, paramScOneInt);
    throwScEx(i);
  }
  
  public static void scGetFmwUpdtState(int paramInt, ScTwoInts paramScTwoInts) throws ScEx {
    int i = getFmwUpdtState(paramInt, paramScTwoInts);
    throwScEx(i);
  }
  
  public static void scExecCmd(int paramInt, String paramString) throws ScEx {
    ScOneString scOneString = new ScOneString(paramString);
    int i = execCmd(paramInt, scOneString);
    throwScEx(i);
  }
  
  public static void main(String[] paramArrayOfString) {
    ScDevPars scDevPars = new ScDevPars();
    try {
      scConnect();
      scSetDevParsToDefaults(0, scDevPars);
    } catch (ScEx scEx) {
      scEx.printStackTrace();
    } 
  }
  
  private static native int isProcessRunning(ScOneString paramScOneString, ScOneBoolean paramScOneBoolean);
  
  private static native int setCurrentUserRegValue(ScThreeStrings paramScThreeStrings);
  
  private static native int queryCurrentUserRegValue(ScTwoStrings paramScTwoStrings, int paramInt, ScOneString paramScOneString);
  
  private static native int delCurrentUserRegValue(ScTwoStrings paramScTwoStrings);
  
  private static native int connect2(ScOneBoolean paramScOneBoolean, ScOneString paramScOneString);
  
  private static native int connect();
  
  private static native int disconnect();
  
  private static native int stop();
  
  private static native int getDmnVrsn(ScTwoStrings paramScTwoStrings);
  
  private static native int getDevNum(ScThreeInts paramScThreeInts);
  
  private static native int getFgAppl(ScTwoStrings paramScTwoStrings);
  
  private static native int getDllLogPars(ScLogPars paramScLogPars);
  
  private static native int setDllLogPars(ScLogPars paramScLogPars);
  
  private static native int setState2(ScOneString paramScOneString);
  
  private static native int setState(ScTwoStrings paramScTwoStrings);
  
  private static native int setMode(ScOneInt paramScOneInt);
  
  private static native int getDevInfo(int paramInt, ScDevInfo paramScDevInfo);
  
  private static native int getDefDevPars(int paramInt, ScDevPars paramScDevPars);
  
  private static native int getDevPars(int paramInt, ScDevPars paramScDevPars);
  
  private static native int setDevPars(int paramInt, ScDevPars paramScDevPars);
  
  private static native int setDevParsToDefaults(int paramInt, ScDevPars paramScDevPars);
  
  private static native int getBasicSettings(int paramInt, ScBasicSettings paramScBasicSettings);
  
  private static native int setBasicSettings(int paramInt, ScBasicSettings paramScBasicSettings);
  
  private static native int getAdvancedSettings(int paramInt, ScAdvancedSettings paramScAdvancedSettings);
  
  private static native int setAdvancedSettings(int paramInt, ScAdvancedSettings paramScAdvancedSettings);
  
  private static native int getAdvSens(int paramInt, ScAdvSens paramScAdvSens);
  
  private static native int setAdvSens(int paramInt, ScAdvSens paramScAdvSens);
  
  private static native int getCfgFileName(int paramInt, ScOneString paramScOneString);
  
  private static native int saveDevPars(int paramInt, ScOneString paramScOneString);
  
  private static native int loadDevPars(int paramInt, ScOneString paramScOneString, ScDevPars paramScDevPars);
  
  private static native int getStdMode(int paramInt, ScOneByte paramScOneByte);
  
  private static native int setStdMode(int paramInt, ScOneByte paramScOneByte);
  
  private static native int getCmprMode(int paramInt, ScOneByte paramScOneByte);
  
  private static native int setCmprMode(int paramInt, ScOneByte paramScOneByte);
  
  private static native int getSens(int paramInt, ScTwoInts paramScTwoInts);
  
  private static native int setSens(int paramInt, ScTwoInts paramScTwoInts);
  
  private static native int getXTraSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setXTraSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int getYTraSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setYTraSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int getZTraSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setZTraSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int getXRotSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setXRotSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int getYRotSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setYRotSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int getZRotSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setZRotSens(int paramInt, ScOneInt paramScOneInt);
  
  private static native int getSendDelay(int paramInt, ScTwoInts paramScTwoInts);
  
  private static native int setSendDelay(int paramInt, ScTwoInts paramScTwoInts);
  
  private static native int getNullRad(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setNullRad(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setStdZero(int paramInt);
  
  private static native int getStdData(int paramInt, ScStdData paramScStdData);
  
  private static native int fetchStdData(int paramInt, ScStdData paramScStdData);
  
  private static native int getRawData(int paramInt, byte[] paramArrayOfbyte);
  
  private static native int getTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getXTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setXTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getYTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setYTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getZTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setZTra(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getXTraRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setXTraRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getYTraRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setYTraRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getZTraRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setZTraRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getXRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setXRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getYRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setYRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getZRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setZRot(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getXRotRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setXRotRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getYRotRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setYRotRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getZRotRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setZRotRev(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int getDom(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int setDom(int paramInt, ScOneBoolean paramScOneBoolean);
  
  private static native int pressKey(int paramInt1, int paramInt2);
  
  private static native int relKey(int paramInt1, int paramInt2);
  
  private static native int triggerFunction(int paramInt1, int paramInt2);
  
  private static native int setLeds(int paramInt, ScThreeInts paramScThreeInts);
  
  private static native int getLedsEx(int paramInt, byte[] paramArrayOfbyte);
  
  private static native int setLedsEx(int paramInt, byte[] paramArrayOfbyte);
  
  private static native int getLed(int paramInt1, int paramInt2, ScOneInt paramScOneInt);
  
  private static native int setLed(int paramInt1, int paramInt2, ScOneInt paramScOneInt);
  
  private static native int getLcd(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setLcd(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setLcdColor(int paramInt, ScThreeInts paramScThreeInts);
  
  private static native int setDsplString(int paramInt1, int paramInt2, String paramString, ScOneInt paramScOneInt);
  
  private static native int getFmwUpdtState(int paramInt, ScTwoInts paramScTwoInts);
  
  private static native int execCmd(int paramInt, ScOneString paramScOneString);
  
  private static native int getDaemonPar(int paramInt, ScOneInt paramScOneInt);
  
  private static native int setDaemonPar(int paramInt, ScOneInt paramScOneInt);
  
  static {
    ArrayList<String> arrayList = new ArrayList();
    boolean bool = false;
    String str1 = System.getProperty("os.name");
    String str2 = System.getProperty("user.dir");
    if (str1.equals("Mac OS X")) {
      arrayList.add(str2 + "/lib/libspc_ctrl_64.dylib");
      arrayList.add(str2 + "/../SC_DLL/dist/ReleaseOSX64/GNU-MacOSX/libspc_ctrl_64.dylib");
      bool = loadLibrary(arrayList);
    } else if (str1.equals("Linux")) {
      arrayList.add(str2 + "/lib/libspc_ctrl.so");
      arrayList.add(str2 + "/../SC_DLL/dist/ReleaseLinux64/GNU-Linux/libspc_ctrl_64.so.2.9.2");
      arrayList.add(str2 + "/../SC_DLL/dist/ReleaseLinux/GNU-Linux/libspc_ctrl_32.so.2.9.2");
      bool = loadLibrary(arrayList);
    } else if (str1.startsWith("Windows")) {
      arrayList.add(str2 + "\\libs\\win32\\spc_ctrlr_32.dll");
      arrayList.add(str2 + "\\libs\\win64\\spc_ctrlr_64.dll");
      arrayList.add(str2 + "\\..\\SC_DLL\\dist\\Release\\spc_ctrlr_32.dll");
      arrayList.add(str2 + "\\..\\SC_DLL\\dist\\Release\\spc_ctrlr_64.dll");
      arrayList.add(str2 + "\\..\\SC_DLL\\dist\\Debug\\spc_ctrlr_32.dll");
      arrayList.add(str2 + "\\..\\SC_DLL\\dist\\Debug\\spc_ctrlr_64.dll");
      bool = loadLibrary(arrayList);
    } else {
      JOptionPane.showMessageDialog(null, "Operating system '" + str1 + "' not supported!", "Load Error", 0);
    } 
  }
}


/* Location:              /opt/SpaceControl/lib/SC_DLL_Wrapper.jar!/de/spacecontrol/sc/dllwrapper/ScDllWrapper.class
 * Java compiler version: 8 (52.0)
 * JD-Core Version:       1.2.1
 */